<?php
namespace AweBooking\Payment\Gateways\Unofficial;

use Awethemes\Http\Request;
use AweBooking\Model\Booking;
use AweBooking\Payment\Gateways\Omnipay_Gateway;

class PayU_Latam_Gateway extends Omnipay_Gateway {
	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->method             = 'payu_latam';
		$this->supports           = [ 'transaction_id' ];
		$this->method_title       = esc_html__( 'PayU (Latam)', 'awebooking-payment' );

		// $message = abrs_esc_text( 'If you do not already have PayU merchant account, please register in <a href="https://secure.payu.com/boarding/#/form" target="_blank">Production</a> or <a href="https://secure.snd.payu.com/boarding/#/form" target="_blank">Sandbox</a>.', 'awebooking-payment' );
		$this->method_description = esc_html__( 'PayU (Latam) payment gateway.', 'awebooking-payment' );
	}

	/**
	 * {@inheritdoc}
	 */
	public function setup() {
		$this->setting_fields();

		$this->enabled     = $this->get_option( 'enabled' );
		$this->title       = esc_html( $this->get_option( 'title' ) );
		$this->description = esc_textarea( $this->get_option( 'description' ) );

		$this->gateway = $this->create_gateway( 'PayULatam', [
			'merchantId' => $this->get_option( 'merchant_id' ),
			'apiKey'     => $this->get_option( 'api_key' ),
			'accountId'  => $this->get_option( 'account_id' ),
			'testMode'   => 'on' === $this->get_option( 'sandbox', 'off' ),
		]);
	}

	/**
	 * Set the gateway settings fields.
	 *
	 * @return void
	 */
	protected function setting_fields() {
		$this->setting_fields = [
			'enabled' => [
				'name'    => esc_html__( 'Enable / Disable', 'awebooking-payment' ),
				'type'    => 'toggle',
				'label'   => esc_html__( 'Enable check payments', 'awebooking-payment' ),
				'default' => 'off',
			],
			'title' => [
				'name'        => esc_html__( 'Title', 'awebooking-payment' ),
				'type'        => 'text',
				'description' => esc_html__( 'This controls the title which the user sees during checkout.', 'awebooking-payment' ),
				'default'     => _x( 'PayU (Latam)', 'PayU payment method', 'awebooking-payment' ),
			],
			'description' => [
				'name'        => esc_html__( 'Description', 'awebooking-payment' ),
				'type'        => 'textarea',
				'description' => esc_html__( 'Payment method description that the customer will see on your checkout.', 'awebooking-payment' ),
				'default'     => esc_html__( 'PayU is a leading payment services provider with presence in 16 growth markets across the world', 'awebooking-payment' ),
			],
			'sandbox' => [
				'type'    => 'toggle',
				'name'    => esc_html__( 'PayU Sandbox', 'awebooking-payment' ),
				'default' => 'off',
			],
			'merchant_id' => [
				'type' => 'text',
				'name' => esc_html__( 'Merchant ID', 'awebooking-payment' ),
			],
			'api_key' => [
				'type' => 'text',
				'name' => esc_html__( 'API Key', 'awebooking-payment' ),
			],
			'account_id' => [
				'type' => 'text',
				'name' => esc_html__( 'Account ID', 'awebooking-payment' ),
			],
		];
	}

	/**
	 * {@inheritdoc}
	 */
	protected function get_purchase_parameters( Booking $booking, Request $request ) {
		return [
			'notifyUrl'     => $this->get_notify_purchase_url( $booking ),
			'transactionId' => uniqid( $booking->get_booking_number() . '_', true ),
			'buyerEmail'    => $booking->get( 'customer_email' ),
		];
	}

	/**
	 * {@inheritdoc}
	 */
	protected function get_complete_purchase_parameters( Booking $booking ) {
		return [
		];
	}
}
